@@ -12,16 +12,12 @@ import logging
 import json
 from functools import reduce
 from time import sleep
-
 import requests
 import os
-
 from urllib.parse import urljoin
 
-from ..config import CONFIG
-from .. import utils
-from time import sleep
-
+from ldf_adapter.config import CONFIG
+from ldf_adapter import utils
 from ldf_adapter.logsetup import jsonlogger
 
 logger = logging.getLogger(__name__)
@@ -34,13 +30,11 @@ class BwIdmConnection:
         self.session = requests.Session()
         if config:
             self.session.auth = (
-                config["backend.bwidm.auth"]["http_user"],
-                config["backend.bwidm.auth"]["http_pass"],
+                config.backend.bwidm.http_user,
+                config.backend.bwidm.http_pass,
             )
 
-        if not CONFIG["backend.bwidm"].getboolean(
-            "log_outgoing_http_requests", fallback=False
-        ):
+        if not CONFIG.backend.bwidm.log_outgoing_http_requests:
             logging.getLogger("requests").setLevel(logging.CRITICAL)
             logging.getLogger("werkzeug").setLevel(logging.CRITICAL)
             logging.getLogger("urllib3").setLevel(logging.CRITICAL)
@@ -63,15 +57,11 @@ class BwIdmConnection:
         fail = kwargs.pop("fail", True)
 
         url_fragments = map(str, url_fragments)
-        url_fragments = map(
-            lambda frag: requests.utils.quote(frag, safe=""), url_fragments
-        )
+        url_fragments = map(lambda frag: requests.utils.quote(frag, safe=""), url_fragments)
         url = reduce(
-            lambda acc, frag: urljoin(acc, frag)
-            if acc.endswith("/")
-            else urljoin(acc + "/", frag),
+            lambda acc, frag: urljoin(acc, frag) if acc.endswith("/") else urljoin(acc + "/", frag),
             url_fragments,
-            CONFIG["backend.bwidm"]["url"],
+            CONFIG.backend.bwidm.url,
         )
 
         # logger.debug(f"BWIDM: {url}")
@@ -81,9 +71,7 @@ class BwIdmConnection:
 
         if fail:
             if not rsp.ok:
-                logger.error(
-                    "Server responded with: {}".format(rsp.content.decode("utf-8"))
-                )
+                logger.error("Server responded with: {}".format(rsp.content.decode("utf-8")))
             rsp.raise_for_status()
 
         return rsp
@@ -100,7 +88,6 @@ class User:
 
     def __init__(self, userinfo):
         self.info = userinfo
-        self.credentials = {}
         self.primary_group = Group(userinfo.primary_group)
         self.force_username = None
 
@@ -121,9 +108,7 @@ class User:
 
     def _is_active(self):
         status = self.reg_info()["userStatus"]
-        logger.debug(
-            "User {} is {} on service BWIDM".format(self.info.unique_id, status)
-        )
+        logger.debug("User {} is {} on service BWIDM".format(self.info.unique_id, status))
         return status == self.VALUE_USER_ACTIVE
 
     def _is_registered(self):
@@ -132,18 +117,14 @@ class User:
         service, identified by its service short name
         """
         # FIXME: Consider putting this request into the global user object (to reduce load on regapp)
-        ssn = CONFIG["backend.bwidm.service"]["name"]
-        registrations = BWIDM.get(
-            "external-reg", "find", "externalId", self.info.unique_id
-        )
+        ssn = CONFIG.backend.bwidm.service_name
+        registrations = BWIDM.get("external-reg", "find", "externalId", self.info.unique_id)
         # find registrations
         number_of_registrations = 0
         try:
             logger.debug("logging registrations to jsonlog")
             jsonlogger.debug(
-                json.dumps(
-                    registrations.json, sort_keys=True, indent=4, separators=(",", ": ")
-                )
+                json.dumps(registrations.json, sort_keys=True, indent=4, separators=(",", ": "))
             )
         except TypeError:
             pass
@@ -168,9 +149,7 @@ class User:
         ).json()
 
         other_users_with_name = [
-            user
-            for user in users_with_name
-            if user["externalId"] != self.info.unique_id
+            user for user in users_with_name if user["externalId"] != self.info.unique_id
         ]
         # logger.debug (F"other_users: {other_users_with_name}")
         logger.debug(f"Found {len(other_users_with_name)} with same username")
@@ -182,9 +161,7 @@ class User:
             logger.error(
                 "Username '{}' is already used by\n    {}".format(
                     self.info.username,
-                    ",\n    ".join(
-                        map(lambda u: u["externalId"], other_users_with_name)
-                    ),
+                    ",\n    ".join(map(lambda u: u["externalId"], other_users_with_name)),
                 )
             )
         else:
@@ -199,8 +176,7 @@ class User:
             """Safely convert a response to json"""
             if resp.status_code != 200:
                 logger.debug(
-                    "Error %d reading from remote: \n%s\n"
-                    % (resp.status_code, str(resp.text))
+                    "Error %d reading from remote: \n%s\n" % (resp.status_code, str(resp.text))
                 )
                 os._exit(1)  # or raise or return None?
             try:
@@ -224,9 +200,7 @@ class User:
             logger.error("Error: I could not find the username in the database.")
             logger.error("  Most likely the user is not registered for this service\n")
             logger.error(f"  {e}")
-            logger.error(
-                json.dumps(resp_json, sort_keys=True, indent=4, separators=(",", ": "))
-            )
+            logger.error(json.dumps(resp_json, sort_keys=True, indent=4, separators=(",", ": ")))
         return None
 
     def set_username(self, username):
@@ -236,7 +210,7 @@ class User:
 
     def set_prefixed_username(self, prefixed_username):
         """Update the internal representation of the user with the incoming username"""
-        bwIdmOrgId = CONFIG["backend.bwidm"]["org_id"]
+        bwIdmOrgId = CONFIG.backend.bwidm.org_id
         username = prefixed_username.lstrip(f"{bwIdmOrgId}_")
         self.set_username(username)
 
@@ -247,9 +221,7 @@ class User:
             BWIDM.get("external-user", "activate", "externalId", self.info.unique_id)
         else:
             logger.info("Creating user {unique_id}".format(**self.info))
-            BWIDM.post(
-                "external-user", "create", json={"externalId": self.info.unique_id}
-            )
+            BWIDM.post("external-user", "create", json={"externalId": self.info.unique_id})
 
     def register(self):
         """register user for the configured service"""
@@ -258,9 +230,7 @@ class User:
             rsp = BWIDM.get("external-reg", "find", "externalId", ext_id)
 
             try:
-                return next(
-                    filter(lambda reg: reg["registryStatus"] == "ACTIVE", rsp.json())
-                )
+                return next(filter(lambda reg: reg["registryStatus"] == "ACTIVE", rsp.json()))
             except StopIteration:
                 return {"lastReconcile": None}
 
@@ -281,7 +251,7 @@ class User:
                 "externalId",
                 self.info.unique_id,
                 "ssn",
-                CONFIG["backend.bwidm.service"]["name"],
+                CONFIG.backend.bwidm.service_name,
             )
 
             if rsp.status_code == 204:
@@ -309,7 +279,7 @@ class User:
                 "primaryGroup": {"id": self.primary_group.reg_info()["id"]},
                 "attributeStore": {
                     self.ATTR_USERNAME: self.force_username or self.info.username,
-                    self.ATTR_ORG_ID: CONFIG["backend.bwidm"]["org_id"],
+                    self.ATTR_ORG_ID: CONFIG.backend.bwidm.org_id,
                 },
             }
         )
@@ -317,13 +287,6 @@ class User:
         if not self._is_registered():
             self.register()
 
-        self.credentials["ssh_user"] = self.get_username()
-        self.credentials["ssh_host"] = CONFIG["backend.bwidm.login_info"].get(
-            "ssh_host", "undefined"
-        )
-        self.credentials["commandline"] = "ssh {}@{}".format(
-            self.credentials["ssh_user"], self.credentials["ssh_host"]
-        )
         logger.debug(f"user is active: {self._is_active()}")
         logger.debug(f"user is registered: {self._is_registered()}")
 
@@ -335,7 +298,7 @@ class User:
             "externalId",
             self.info.unique_id,
             "ssn",
-            CONFIG["backend.bwidm.service"]["name"],
+            CONFIG.backend.bwidm.service_name,
         )
 
     def deactivate(self):
@@ -359,16 +322,12 @@ class User:
 
             # Remove user from groups he should not be a member of
             to_be_removed_from = [
-                g
-                for g in current_groups
-                if g["id"] not in (ng["id"] for ng in new_groups)
+                g for g in current_groups if g["id"] not in (ng["id"] for ng in new_groups)
             ]
 
             # Only add user to groups she is not already a member of
             to_be_added_to = [
-                g
-                for g in new_groups
-                if g["id"] not in (cg["id"] for cg in current_groups)
+                g for g in new_groups if g["id"] not in (cg["id"] for cg in current_groups)
             ]
 
             if to_be_removed_from:
@@ -443,9 +402,7 @@ class User:
         """
         current_state = self.reg_info()
         new_state = utils.dictmerge(current_state, state_updates)
-        utils.log_dictdiff(
-            utils.dictdiff(current_state, new_state), log_function=logger.info
-        )
+        utils.log_dictdiff(utils.dictdiff(current_state, new_state), log_function=logger.info)
         try:
             logger.debug(
                 f"current_state: {current_state['attributeStore']['urn:oid:0.9.2342.19200300.100.1.1']}"
@@ -479,9 +436,7 @@ class User:
             jsonlogger.debug(f"current_state: {formatted_json}")
 
             logger.debug("  logging new_to jsonlog")
-            formatted_json = json.dumps(
-                new_state, sort_keys=True, indent=4, separators=(",", ": ")
-            )
+            formatted_json = json.dumps(new_state, sort_keys=True, indent=4, separators=(",", ": "))
             jsonlogger.debug(f"new state for regapp:  {formatted_json}")
         except:
             pass
@@ -489,9 +444,7 @@ class User:
 
     def reg_info(self, json=True, **kwargs):
         # FIXME: Cache this functions results!
-        rsp = BWIDM.get(
-            "external-user", "find", "externalId", self.info.unique_id, **kwargs
-        )
+        rsp = BWIDM.get("external-user", "find", "externalId", self.info.unique_id, **kwargs)
         return rsp.json() if json else rsp.content
 
 
@@ -501,24 +454,20 @@ class Group:
 
     def exists(self):
         # FIXME: Group existence needs to be checked with using also
-        # CONFIG['backend.bwidm.service']['name']
+        # CONFIG.backend.bwidm.service_name
         return (
             b"no such group"
-            not in BWIDM.get(
-                "group-admin", "find", "name", self.name, fail=False
-            ).content
+            not in BWIDM.get("group-admin", "find", "name", self.name, fail=False).content
         )
 
     def create(self):
         rsp = BWIDM.get(
-            "group-admin", "create", CONFIG["backend.bwidm.service"]["name"], self.name
+            "group-admin", "create", CONFIG.backend.bwidm.service_name, self.name
         ).json()
 
         if self.name != rsp["name"]:
             logger.warning(
-                "Groupname changed from {} to {} by BWIDM".format(
-                    self.name, rsp["name"]
-                )
+                "Groupname changed from {} to {} by BWIDM".format(self.name, rsp["name"])
             )
             self.name = rsp["name"]
 
